# Instructions:
# * Ensure you have the following R libraries installed via the following:
#   install.packages(c("reticulate", "stringr", "roxygen2))`
# * Change variable `pkg_location` below to point to your R package directory

library(reticulate)
library(stringr)
library(roxygen2)
pkg_location <- "~/repos/io/R-package"

setwd(pkg_location)
tfio_lib <- import("tensorflow_io")

source(paste0(pkg_location, "scripts/gen_wrapper_utils.R"))

generated_wrappers_file_name <- "R/auto_generated_wrappers.R"
write(paste0(
  "# -------------------------------------------------------------------------------
#             *** WARNING: DO NOT MODIFY THIS FILE ***
#
# Instead, modify scripts/gen_wrappers.R which automatically generates this file.\n#\n",
  "# Generated by reticulate v", packageVersion("reticulate"),
  "\n# ------------------------------------------------------------------------------- \n"
), file = generated_wrappers_file_name)

py_function_custom_scaffold(
  "tfio_lib$kafka$KafkaDataset",
  r_function = "kafka_dataset",
  process_param_fn = process_int_param_fn,
  postprocess_fn = tf_dataset_postprocess_fn,
  file_name = generated_wrappers_file_name)

py_function_custom_scaffold(
  "tfio_lib$ignite$IgniteDataset",
  r_function = "ignite_dataset",
  process_param_fn = process_int_param_fn,
  postprocess_fn = tf_dataset_postprocess_fn,
  file_name = generated_wrappers_file_name)

py_function_custom_scaffold(
  "tfio_lib$kinesis$KinesisDataset",
  r_function = "kinesis_dataset",
  process_param_fn = process_int_param_fn,
  postprocess_fn = tf_dataset_postprocess_fn,
  file_name = generated_wrappers_file_name)

py_function_custom_scaffold(
  "tfio_lib$hadoop$SequenceFileDataset",
  r_function = "sequence_file_dataset",
  process_param_fn = process_int_param_fn,
  postprocess_fn = tf_dataset_postprocess_fn,
  file_name = generated_wrappers_file_name)

# Regenerate NAMESPACE and .Rd files
roxygen2::roxygenise(pkg_location)
